%define relbuild 2024-10-09_e7c3feb100

%ifarch aarch64
  %global _smp_ncpus_max 4
%endif

Name:           inkscape
Summary:        A vector-based drawing program using SVG
Version:        1.4
Release:        %mkrel 3
License:        GPLv2+
Group:          Graphics/Editors and Converters
URL:            https://inkscape.org/
Source0:        https://media.inkscape.org/dl/resources/file/%{name}-%{version}.tar.xz
#
# from git upstream (https://gitlab.com/inkscape/inkscape.git)
#
Patch1:		0001-Future-proof-against-poppler-24.10-changes.patch
Patch2:		0001-Fix-building-with-Poppler-24.11.patch
Patch3:		0001-Fix-building-with-poppler-24.12.0.patch
#
Patch100:       inkscape-rpath.patch

BuildRequires:  ninja
BuildRequires:  cmake
BuildRequires:  cmake(double-conversion)
BuildRequires:  pkgconfig(2geom) >= 1.2.2
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(cairo-pdf)
BuildRequires:  pkgconfig(cairo-svg)
BuildRequires:  pkgconfig(gdkmm-3.0)
BuildRequires:  pkgconfig(glibmm-2.4)
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(GraphicsMagick++)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(gtkspell3-3.0)
BuildRequires:  pkgconfig(gtksourceview-4)
BuildRequires:  pkgconfig(Magick++)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libcdr-0.1)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(librevenge-stream-0.0)
BuildRequires:  pkgconfig(libvisio-0.1)
BuildRequires:  pkgconfig(libwpg-0.3)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(poppler)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(sigc++-2.0)
BuildRequires:  pkgconfig(bdw-gc)
BuildRequires:  pkgconfig(readline)
BuildRequires:  perl(XML::Parser)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(cython)
BuildRequires:  boost-devel
BuildRequires:  perl
BuildRequires:  perl-devel
BuildRequires:  pkgconfig(popt)
BuildRequires:  potrace-devel
BuildRequires:  desktop-file-utils
BuildRequires:  intltool
BuildRequires:  gettext-devel
Requires:       python3-appdirs
Requires:       python3-cssselect
Requires:       python3-gobject
Requires:       python3-lxml
Requires:       python3-numpy
Requires:       python3-pillow
Requires:       python3-requests
Requires:       python3-scour
Requires:       graphicsmagick
Recommends:     uniconvertor

%description
Inkscape is a generic SVG-based vector-drawing program.

Inkscape uses the W3C SVG (= "Scalable Vector Graphics") standard as its
native file format. Therefore, it is a very useful tool for web designers
and can be used as an interchange format for desktop publishing.

%prep
%autosetup -p1 -n inkscape-%{version}_%{relbuild}

# fix python shebangs
%py3_shebang_fix share/extensions/

# workaround CMake Error: failed to create symbolic link
# /build/inkscape_datadir/inkscape': no such file or directory
mkdir -p %{_vpath_builddir}/inkscape_datadir/

%build
# When WITH_IMAGE_MAGICK=OFF is set, it defaults to Graphicsmagick.
%cmake -GNinja \
       -DWITH_IMAGE_MAGICK=OFF \
       -DWITH_MANPAGE_COMPRESSION=OFF

%cmake_build

%install
%cmake_install

perl -i -lne 'print unless m{^\[Drawing Shortcut Group\]}..1' %{buildroot}%{_datadir}/applications/*

desktop-file-install --vendor="" \
  --add-category="Graphics;2DGraphics" \
  --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/*

%find_lang %{name} --with-man --all-name

%files -f %{name}.lang
%doc AUTHORS NEWS.md README.md
%license COPYING
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/inkscape/
%{_metainfodir}/org.inkscape.Inkscape.appdata.xml
%{_mandir}/man1/*
%{_iconsdir}/hicolor/*/apps/*
%{_libdir}/inkscape/


%changelog
* Sun Feb 09 2025 wally <wally> 1.4-3.mga10
+ Revision: 2146230
- rebuild for boost 1.87.0

* Mon Feb 03 2025 wally <wally> 1.4-2.mga10
+ Revision: 2144918
- rebuild for poppler 25.01.0

* Mon Oct 14 2024 daviddavid <daviddavid> 1.4-1.mga10
+ Revision: 2106707
- new version: 1.4
- remove merged upstream patches

* Fri Sep 27 2024 daviddavid <daviddavid> 1.3.2-8.mga10
+ Revision: 2101609
- backport upstream patch for new 2geom 1.4
- remove unneeded gdl build dependency

* Thu Sep 19 2024 daviddavid <daviddavid> 1.3.2-7.mga10
+ Revision: 2099047
- rebuild for new gspell 1.14.0

* Fri Sep 13 2024 wally <wally> 1.3.2-6.mga10
+ Revision: 2095476
- rebuild for boost 1.86.0

* Wed Jun 19 2024 wally <wally> 1.3.2-5.mga10
+ Revision: 2075347
- rebuild for boost 1.85.0

* Sun Jun 09 2024 wally <wally> 1.3.2-4.mga10
+ Revision: 2072092
- build using C++20
- rebuild for poppler 24.06.0

* Thu May 02 2024 daviddavid <daviddavid> 1.3.2-3.mga10
+ Revision: 2061837
- rebuild against current libs (mga#33165)

* Sat Jan 13 2024 daviddavid <daviddavid> 1.3.2-2.mga10
+ Revision: 2030768
- backport upstream patch to fix build with libxml2 >= 2.12
+ wally <wally>
- rebuild for boost 1.84.0

* Mon Nov 27 2023 daviddavid <daviddavid> 1.3.2-1.mga10
+ Revision: 2009944
- new version: 1.3.2

* Thu Oct 12 2023 wally <wally> 1.3-4.mga10
+ Revision: 1994955
- switch to libsoup3.0

* Wed Sep 27 2023 wally <wally> 1.3-3.mga10
+ Revision: 1991451
- rebuild for boost 1.83.0

* Tue Sep 05 2023 wally <wally> 1.3-2.mga10
+ Revision: 1984487
- rebuild for poppler 23.08.0

* Tue Sep 05 2023 daviddavid <daviddavid> 1.3-1.mga10
+ Revision: 1984234
- new version: 1.3
- remove merged upstream patches
+ wally <wally>
- drop unneeded QA_RPATHS export

* Mon Feb 13 2023 ghibo <ghibo> 1.2.2-4.mga9
+ Revision: 1941336
- Skip QA_RPATHS for now
- Rebuild against newer libpoppler
+ wally <wally>
- fix rpath patch

* Thu Dec 29 2022 daviddavid <daviddavid> 1.2.2-3.mga9
+ Revision: 1927510
- rebuild for new gsl 2.7.1

* Sat Dec 24 2022 wally <wally> 1.2.2-2.mga9
+ Revision: 1926482
- rebuild for boost 1.81.0

* Fri Dec 09 2022 ghibo <ghibo> 1.2.2-1.mga9
+ Revision: 1920121
- Update to release 1.2.2.
- Remove Patch1 merged upstream.
- Merge patches from upstream fixing some crash/memleak.

* Sat Dec 03 2022 wally <wally> 1.2.1-4.mga9
+ Revision: 1916203
- rebuild for poppler 22.12.0

* Fri Nov 18 2022 akien <akien> 1.2.1-3.mga9
+ Revision: 1908750
- Require python3-cssselect for inkex extension

* Mon Oct 24 2022 ghibo <ghibo> 1.2.1-2.mga9
+ Revision: 1899131
- Rebuild against newer libpoppler

* Sun Sep 04 2022 wally <wally> 1.2.1-1.mga9
+ Revision: 1883752
- new version 1.2.1
- rebuild for poppler 22.09.0

* Sat Jul 23 2022 wally <wally> 1.1.2-3.mga9
+ Revision: 1870367
- rebuild for poppler 22.07.0

* Sun Jul 03 2022 wally <wally> 1.1.2-2.mga9
+ Revision: 1867261
- rebuild for boost 1.79.0

* Sun May 15 2022 wally <wally> 1.1.2-1.mga9
+ Revision: 1858298
- new version 1.1.2

* Sun May 15 2022 wally <wally> 1.1.1-7.mga9
+ Revision: 1858263
- rebuild for poppler 22.05.0

* Sun May 01 2022 wally <wally> 1.1.1-6.mga9
+ Revision: 1855374
- rebuild for poppler 22.04.0

* Sat Mar 19 2022 tv <tv> 1.1.1-5.mga9
+ Revision: 1801522
- Rebuild for new poppler

* Wed Dec 22 2021 wally <wally> 1.1.1-4.mga9
+ Revision: 1763300
- rebuild for missing pkgs in armv7hl

* Sun Dec 19 2021 wally <wally> 1.1.1-3.mga9
+ Revision: 1762605
- rebuild for boost 1.78.0

* Sun Dec 19 2021 wally <wally> 1.1.1-2.mga9
+ Revision: 1762532
- rebuild for poppler 21.12.0

* Sun Nov 07 2021 wally <wally> 1.1.1-1.mga9
+ Revision: 1754576
- new version 1.1.1

* Sun Nov 07 2021 wally <wally> 1.1-9.mga9
+ Revision: 1754571
- rebuild for poppler 21.11.0

* Thu Sep 09 2021 wally <wally> 1.1-8.mga9
+ Revision: 1744703
- rebuild for boost 1.77.0

* Wed Sep 08 2021 wally <wally> 1.1-7.mga9
+ Revision: 1744503
- rebuild for poppler 21.09.0

* Thu Aug 12 2021 wally <wally> 1.1-6.mga9
+ Revision: 1741201
- rebuild for poppler 21.08.0

* Sat Jun 19 2021 wally <wally> 1.1-5.mga9
+ Revision: 1731286
- rebuild for poppler 21.06.1

* Thu May 27 2021 daviddavid <daviddavid> 1.1-4.mga9
+ Revision: 1728640
- finally remove previous ld.so.conf.d config file and fix properly cmake rpath

* Thu May 27 2021 daviddavid <daviddavid> 1.1-3.mga9
+ Revision: 1728583
- add ld.so.conf.d config for libraries outside the standard search path

* Thu May 27 2021 daviddavid <daviddavid> 1.1-2.mga9
+ Revision: 1728582
- add some missing python3 dependencies (appdirs, gobject, numpy, pillow and scour)

* Wed May 26 2021 daviddavid <daviddavid> 1.1-1.mga9
+ Revision: 1728338
- new version: 1.1
- remove merged upstream patches
- create "build/inkscape_datadir/" folder before build to fix cmake error

* Mon Apr 12 2021 daviddavid <daviddavid> 1.0.2-3.mga9
+ Revision: 1715189
- add fedora patches to fix FTBFS
- add upstream patch to update gcodetools.py to fix a bug with area creation
  where a conversion to string no longer worked in Inkscape 1.0 and changed
  an indentation so that the d parameter is correctly exported for dynamic
  offsets (mga#28760)

* Sat Mar 20 2021 wally <wally> 1.0.2-2.mga9
+ Revision: 1705887
- rebuild for poppler 21.03.0

* Fri Jan 29 2021 kekepower <kekepower> 1.0.2-1.mga8
+ Revision: 1674028
- Update to version 1.0.2

* Tue Dec 29 2020 daviddavid <daviddavid> 1.0.1-3.mga8
+ Revision: 1664786
- add upstream patch to add missing atomic include
  * https://gitlab.com/inkscape/inkscape/-/issues/1798

* Sun Dec 06 2020 wally <wally> 1.0.1-2.mga8
+ Revision: 1653296
- rebuild for poppler 20.12.0

* Tue Sep 08 2020 shlomif <shlomif> 1.0.1-1.mga8
+ Revision: 1623422
- New version 1.0.1

* Thu Aug 06 2020 wally <wally> 1.0-5.mga8
+ Revision: 1611567
- rebuild for poppler 20.08.0

* Sat May 09 2020 shlomif <shlomif> 1.0-4.mga8
+ Revision: 1582304
- Fix inkscape runtime rpath (could not load .so)

* Thu May 07 2020 shlomif <shlomif> 1.0-3.mga8
+ Revision: 1581438
- reenable shared libs

* Wed May 06 2020 daviddavid <daviddavid> 1.0-2.mga8
+ Revision: 1580820
- switch to gtkspell3
- enable GraphicsMagick support (IMAGEMAGICK support requires version 6)

* Tue May 05 2020 shlomif <shlomif> 1.0-1.mga8
+ Revision: 1580504
- avoid empty libdir-inkscape
- New version 1.0

* Sat May 02 2020 wally <wally> 0.92.5-2.mga8
+ Revision: 1577939
- rebuild for poppler 0.88.0

* Sun Apr 12 2020 daviddavid <daviddavid> 0.92.5-1.mga8
+ Revision: 1566780
- new version: 0.92.5
- remove merged upstream patches

* Sat Apr 04 2020 wally <wally> 0.92.4-16.mga8
+ Revision: 1564400
- really rebuild with poppler 0.87.0

* Sat Apr 04 2020 wally <wally> 0.92.4-15.mga8
+ Revision: 1564375
- rebuild for poppler 0.87.0

* Wed Mar 04 2020 wally <wally> 0.92.4-14.mga8
+ Revision: 1553715
- rebuild for poppler 0.86.1

* Tue Mar 03 2020 wally <wally> 0.92.4-13.mga8
+ Revision: 1553512
- rebuild for poppler 0.86.0

* Wed Feb 19 2020 umeabot <umeabot> 0.92.4-12.mga8
+ Revision: 1544148
- Mageia 8 Mass Rebuild

* Fri Jan 24 2020 wally <wally> 0.92.4-11.mga8
+ Revision: 1482648
- rebuild for poppler 0.84.0

* Mon Dec 23 2019 wally <wally> 0.92.4-10.mga8
+ Revision: 1469671
- rebuild for poppler 0.83.0

* Thu Oct 31 2019 wally <wally> 0.92.4-9.mga8
+ Revision: 1457180
- rebuild for new poppler 0.82.0

* Thu Oct 10 2019 wally <wally> 0.92.4-8.mga8
+ Revision: 1451107
- rebuild for poppler 0.81.0

* Fri Sep 20 2019 wally <wally> 0.92.4-7.mga8
+ Revision: 1444003
- disable python byte compile outside python dirs (allows build to succeed as all extensions aren't ported to python3)
- rebuild for poppler 0.80.0

* Tue Aug 27 2019 daviddavid <daviddavid> 0.92.4-6.mga8
+ Revision: 1433755
- rebuild for new gsl 2.6

* Sun Jul 14 2019 wally <wally> 0.92.4-5.mga8
+ Revision: 1421359
- rebuild with poppler 0.78.0
- add patch via Gentoo to fix build with poppler >= 0.76.0

* Sun Mar 10 2019 wally <wally> 0.92.4-4.mga7
+ Revision: 1373703
- switch to gtkspell3

* Mon Feb 18 2019 wally <wally> 0.92.4-3.mga7
+ Revision: 1368159
- rebuild for new poppler 0.74.0

* Sat Jan 26 2019 wally <wally> 0.92.4-2.mga7
+ Revision: 1361107
- rebuild for new poppler 0.73.0

* Thu Jan 17 2019 shlomif <shlomif> 0.92.4-1.mga7
+ Revision: 1357785
- New version 0.92.4

* Sat Dec 08 2018 wally <wally> 0.92.3-7.mga7
+ Revision: 1339034
- add patch to build with poppler 0.72.0
- fix python script shebangs

* Sat Nov 17 2018 wally <wally> 0.92.3-6.mga7
+ Revision: 1330516
- add patch and rebuild for new poppler 0.71.0
- don't skip rpath when building
- add patch to install modules to %%libdir

* Thu Nov 01 2018 tv <tv> 0.92.3-5.mga7
+ Revision: 1327041
- fix building with new poppler
- rebuild with latest poppler

* Sat Sep 08 2018 wally <wally> 0.92.3-4.mga7
+ Revision: 1257828
- rebuild for aarch64

* Wed May 02 2018 kekepower <kekepower> 0.92.3-3.mga7
+ Revision: 1224485
- Rebuild for ImageMagic 7.0.7.29

* Sun Apr 15 2018 kekepower <kekepower> 0.92.3-2.mga7
+ Revision: 1219056
- Rebuild for new Poppler

* Fri Mar 23 2018 shlomif <shlomif> 0.92.3-1.mga7
+ Revision: 1211606
- New version 0.92.3

* Sun Jan 21 2018 wally <wally> 0.92.2-4.mga7
+ Revision: 1195386
- add patch from lp to fix build with new imagemagick-7 (lp#1675962)
- rebuild for new imagemagick

* Wed Jan 10 2018 ns80 <ns80> 0.92.2-3.mga7
+ Revision: 1192055
- rebuild for new poppler

* Wed Dec 27 2017 wally <wally> 0.92.2-2.mga7
+ Revision: 1185645
- rebuild for new gsl

* Sun Oct 15 2017 shlomif <shlomif> 0.92.2-1.mga7
+ Revision: 1172234
- New version 0.92.2

* Thu Oct 12 2017 tv <tv> 0.92.1-5.mga7
+ Revision: 1171323
- rebuild for new poppler

* Sun Sep 24 2017 cjw <cjw> 0.92.1-4.mga7
+ Revision: 1158623
- patch1: fix build with gcc 7
+ tv <tv>
- fix build with new poppler
- rebuild for new poppler

* Sun Aug 06 2017 daviddavid <daviddavid> 0.92.1-3.mga7
+ Revision: 1138089
- rebuild for new poppler 0.56

* Sat May 27 2017 shlomif <shlomif> 0.92.1-2.mga6
+ Revision: 1105196
- rebuild for new imagemagick

* Thu Feb 16 2017 shlomif <shlomif> 0.92.1-1.mga6
+ Revision: 1086442
- New upstream version 0.92.1

* Wed Jan 18 2017 shlomif <shlomif> 0.92-2.mga6
+ Revision: 1082218
- Add an optional build dep for potrace-devel.

* Wed Jan 04 2017 shlomif <shlomif> 0.92-1.mga6
+ Revision: 1080049
- Add missing cmake dep
- New version 0.92.0 (.spec is crufty due to experiments).

* Mon Jan 02 2017 luigiwalser <luigiwalser> 0.91-14.mga6
+ Revision: 1079508
- rebuild for poppler

* Mon Nov 28 2016 luigiwalser <luigiwalser> 0.91-13.mga6
+ Revision: 1070627
- rebuild for poppler

* Sat Aug 13 2016 luigiwalser <luigiwalser> 0.91-12.mga6
+ Revision: 1046183
- test rebuild for poppler

* Tue Aug 02 2016 ovitters <ovitters> 0.91-11.mga6
+ Revision: 1044300
- disable ancient gnome-vfs

* Sat Jul 02 2016 shlomif <shlomif> 0.91-10.mga6
+ Revision: 1038317
- Hopefully fix MGA#18839 - Visio stencil support.

* Wed May 25 2016 luigiwalser <luigiwalser> 0.91-9.mga6
+ Revision: 1018539
- rebuild for poppler

* Mon May 09 2016 luigiwalser <luigiwalser> 0.91-8.mga6
+ Revision: 1011750
- rebuild for poppler

* Sat Mar 12 2016 pterjan <pterjan> 0.91-7.mga6
+ Revision: 989701
- Fix build with recent glibmm

* Sun Jan 03 2016 luigiwalser <luigiwalser> 0.91-6.mga6
+ Revision: 919007
- rebuild for gsl

* Fri Jan 01 2016 luigiwalser <luigiwalser> 0.91-5.mga6
+ Revision: 917803
- rebuild for poppler

* Thu Aug 27 2015 shlomif <shlomif> 0.91-4.mga6
+ Revision: 870196
- Rebuild due to new ABI and a segfault (verified to fix locally)

* Mon Jul 27 2015 cjw <cjw> 0.91-3.mga6
+ Revision: 858170
- add -std=gnu++11 to CXXFLAGS to fix build with gtkmm
- generate build scripts from sources
+ tv <tv>
- rebuild for new poppler

* Wed Jun 24 2015 fwang <fwang> 0.91-2.mga6
+ Revision: 841888
- rebuild for new imagemagick

* Sun Feb 01 2015 shlomif <shlomif> 0.91-1.mga5
+ Revision: 812962
- New version 0.91

* Sun Nov 30 2014 cjw <cjw> 0.48.5-7.mga5
+ Revision: 800019
- remove apparently obsolete requirement on python-pyxml

* Wed Oct 15 2014 umeabot <umeabot> 0.48.5-6.mga5
+ Revision: 747231
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 0.48.5-5.mga5
+ Revision: 725092
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 0.48.5-4.mga5
+ Revision: 680515
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sat Aug 23 2014 fwang <fwang> 0.48.5-3.mga5
+ Revision: 666794
- rebuild for imagemagick

* Tue Aug 05 2014 luigiwalser <luigiwalser> 0.48.5-2.mga5
+ Revision: 660035
- add patch from fedora to fix build with new libwpg
- rebuild for updated libwp[dgs] libraries

* Mon Jun 23 2014 luigiwalser <luigiwalser> 0.48.5-1.mga5
+ Revision: 638861
- 0.48.5
- remove upstreamed patches 1, 4, and 5

* Sun May 04 2014 tarakbumba <tarakbumba> 0.48.4-15.mga5
+ Revision: 620099
- Fix build with poppler-0.26.0
+ luigiwalser <luigiwalser>
- fix build with new freetype2
- rebuild for poppler

* Sat Oct 19 2013 umeabot <umeabot> 0.48.4-14.mga5
+ Revision: 535187
- Mageia 4 Mass Rebuild

* Thu Sep 19 2013 fwang <fwang> 0.48.4-13.mga4
+ Revision: 481464
- rebuild for new imagemagick

* Tue Sep 10 2013 fwang <fwang> 0.48.4-12.mga4
+ Revision: 477204
- apply patch1
- fix build with recent gcc

* Wed Aug 07 2013 fwang <fwang> 0.48.4-11.mga4
+ Revision: 464403
- rebuild for new imagemagick

* Wed Jul 31 2013 fwang <fwang> 0.48.4-10.mga4
+ Revision: 461345
- rebuild for new poppler

* Sat Jul 20 2013 fwang <fwang> 0.48.4-9.mga4
+ Revision: 456513
- rebuild for new poppler

* Tue Jul 09 2013 fwang <fwang> 0.48.4-8.mga4
+ Revision: 451657
- rebuild for new boost

* Mon Jun 03 2013 fwang <fwang> 0.48.4-7.mga4
+ Revision: 435972
- rebuild for new libpng

* Tue May 28 2013 fwang <fwang> 0.48.4-6.mga4
+ Revision: 429160
- rebuild for new imagemagick

* Fri May 24 2013 fwang <fwang> 0.48.4-5.mga4
+ Revision: 425823
- rebuild for new poppler

* Sat Jan 12 2013 umeabot <umeabot> 0.48.4-4.mga3
+ Revision: 354405
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Editors -> Graphics/Editors and Converters

* Sun Dec 30 2012 fwang <fwang> 0.48.4-3.mga3
+ Revision: 336405
- rebuild for new poppler

* Sun Dec 30 2012 cjw <cjw> 0.48.4-2.mga3
+ Revision: 336338
- patch3: fix build with automake 1.13

* Tue Dec 18 2012 fwang <fwang> 0.48.4-1.mga3
+ Revision: 332409
- build with permissive
- br popt
- apply gc patch
- new version 0.48.4

* Fri Dec 14 2012 fwang <fwang> 0.48.3.1-8.mga3
+ Revision: 330773
- rebuild for new imagemagick

* Mon Nov 12 2012 fwang <fwang> 0.48.3.1-7.mga3
+ Revision: 317123
- rebuild for new poppler

* Fri Oct 12 2012 fwang <fwang> 0.48.3.1-6.mga3
+ Revision: 305129
- rebuild for new imagemagick

* Wed Oct 10 2012 tv <tv> 0.48.3.1-5.mga3
+ Revision: 304196
- fix group
- rebuild with new poppler

* Tue Sep 11 2012 fwang <fwang> 0.48.3.1-4.mga3
+ Revision: 292156
- rebuild for new poppler
- fix category

* Sat Sep 01 2012 fwang <fwang> 0.48.3.1-3.mga3
+ Revision: 286943
- br gettext
- build with -fpermissive
+ tv <tv>
- patch 2: fix build with GC7
- BR libgc-devel
- rebuild for new poppler

* Wed Jun 13 2012 fwang <fwang> 0.48.3.1-2.mga3
+ Revision: 260267
- more pathc
- add inkscape patch to build with latest inkscape
- rebuild for new poppler

* Sun Feb 19 2012 fwang <fwang> 0.48.3.1-1.mga2
+ Revision: 210729
- new version 0.48.3.1

* Thu Feb 16 2012 fwang <fwang> 0.48.3-1.mga2
+ Revision: 209449
- new version 0.48.3

* Sun Feb 05 2012 doktor5000 <doktor5000> 0.48.2-6.mga2
+ Revision: 204729
- added Suggests on uniconvertor (mga#3545)

* Fri Oct 28 2011 fwang <fwang> 0.48.2-5.mga2
+ Revision: 159057
- more revert
- revert some changes
- more fix
- more patch
- more patch
- revert some changes
- include glib.h only
- only include glib header
- rebuild for new poppler

* Tue Sep 27 2011 ovitters <ovitters> 0.48.2-4.mga2
+ Revision: 149383
- rebuild for new poppler

* Tue Sep 13 2011 fwang <fwang> 0.48.2-3.mga2
+ Revision: 142817
- rebuild for new imagemagick

* Mon Sep 12 2011 fwang <fwang> 0.48.2-2.mga2
+ Revision: 142637
- fix build with libpng15
- rebuild for new libpng
+ ahmad <ahmad>
- Change libpoppler-*-devel BR to pkgconfig style

* Sat Jul 09 2011 fwang <fwang> 0.48.2-1.mga2
+ Revision: 121078
- new version 0.48.2

* Sun Mar 27 2011 ahmad <ahmad> 0.48.1-2.mga1
+ Revision: 78072
- rebuild for new poppler

* Thu Feb 10 2011 dmorgan <dmorgan> 0.48.1-1.mga1
+ Revision: 49759
- Remove mdv macros
- imported package inkscape


* Sun Feb 06 2011 Funda Wang <fwang@mandriva.org> 0.48.1-1mdv2011.0
+ Revision: 636421
- New version 0.48.1

* Thu Dec 30 2010 Funda Wang <fwang@mandriva.org> 0.48.0-3mdv2011.0
+ Revision: 626335
- add upstream fix for poppler 0.16.0
- rebuild for new poppler

* Sun Aug 22 2010 Funda Wang <fwang@mandriva.org> 0.48.0-2mdv2011.0
+ Revision: 571802
- rebuild for new poppler

* Sat Aug 14 2010 Funda Wang <fwang@mandriva.org> 0.48.0-1mdv2011.0
+ Revision: 569765
- New version 0.48.0
  * no other distroare using unviconvertor
  * cxxinclude patch not needed
  * poppler patch merged already

* Thu Aug 05 2010 Funda Wang <fwang@mandriva.org> 0.47-5mdv2011.0
+ Revision: 566256
- rebuild for new poppler

* Sat Jul 17 2010 Funda Wang <fwang@mandriva.org> 0.47-4mdv2011.0
+ Revision: 554585
- rebuild
- build with popt
- rebuild for new imagemagick

  + Shlomi Fish <shlomif@mandriva.org>
    - Revise the description to make it better English

* Thu Jan 14 2010 Funda Wang <fwang@mandriva.org> 0.47-2mdv2010.1
+ Revision: 491146
- rebuild for new imagemagick

* Thu Nov 26 2009 Pascal Terjan <pterjan@mandriva.org> 0.47-1mdv2010.1
+ Revision: 470389
- Add a patch fixing build against poppler 0.12.2
- Update to 0.47 final

* Sun Nov 08 2009 Lev Givon <lev@mandriva.org> 0.47-0.pre4.1mdv2010.1
+ Revision: 463125
- Update to 0.47pre4.

* Tue Oct 06 2009 Lev Givon <lev@mandriva.org> 0.47-0.pre3.1mdv2010.0
+ Revision: 454410
- Update to 0.47pre3.

* Thu Sep 03 2009 Pascal Terjan <pterjan@mandriva.org> 0.47-0.pre2.1mdv2010.0
+ Revision: 428248
- Update to 0.47 pre2

  + Nicolas Lécureuil <nlecureuil@mandriva.com>
    - Rebuild against new perl

* Tue May 19 2009 Götz Waschk <waschk@mandriva.org> 0.46-12mdv2010.0
+ Revision: 377635
- fix build with gcc 4.4
- remove old configure options
- fix adjustments with current gtk

* Tue May 19 2009 Götz Waschk <waschk@mandriva.org> 0.46-11mdv2010.0
+ Revision: 377606
- fix makefile
- rebuild for new poppler

* Wed Jan 28 2009 Götz Waschk <waschk@mandriva.org> 0.46-10mdv2009.1
+ Revision: 335033
- rebuild for new libmagick

* Wed Jan 14 2009 Jérôme Soyer <saispo@mandriva.org> 0.46-9mdv2009.1
+ Revision: 329551
- Rebuild with python2.6

* Sun Sep 28 2008 Frederik Himpe <fhimpe@mandriva.org> 0.46-8mdv2009.0
+ Revision: 289079
- Fix perl support build with perl 5.10
- Fix build with libmagick++
- Add mime type for compressed svg files to desktop files and don't
  add extension to icon name

* Fri Sep 26 2008 Oden Eriksson <oeriksson@mandriva.com> 0.46-7mdv2009.0
+ Revision: 288617
- rebuild against the correct version of the libgc library

* Thu Sep 11 2008 Frederik Himpe <fhimpe@mandriva.org> 0.46-6mdv2009.0
+ Revision: 283941
- Add patches from Debian and Fedora
  * fixing build with poppler 0.8.3 and gtk+ 2.13 and include fixes
  * fixing crash with zh_CN locale when using gtk+ file chooser
  * fixing gtk+ file dialog not showing last used directory

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Thu May 01 2008 Funda Wang <fwang@mandriva.org> 0.46-5mdv2009.0
+ Revision: 199793
- rebuild

* Wed Apr 23 2008 Giuseppe Ghibò <ghibo@mandriva.com> 0.46-4mdv2009.0
+ Revision: 196789
- Add support for ImageMagick in BuildRequires. Sound inkscape configure detect
  is broken with Magick++.h, so need to pass through CPPFLAGS.

* Tue Apr 22 2008 Lev Givon <lev@mandriva.org> 0.46-3mdv2009.0
+ Revision: 196597
- lxml is needed to run Inkscape extensions.

* Sun Apr 20 2008 Pascal Terjan <pterjan@mandriva.org> 0.46-2mdv2009.0
+ Revision: 195955
- Add more missing buildrequires to get all features

* Sun Apr 20 2008 Pascal Terjan <pterjan@mandriva.org> 0.46-1mdv2009.0
+ Revision: 195913
- BuildRequires boost-devel
- Update to 0.46

* Thu Feb 07 2008 Funda Wang <fwang@mandriva.org> 0.45.1-5mdv2008.1
+ Revision: 163569
- add ubuntu patch to have it built against latest glib
- drop old menu

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Sep 17 2007 Pascal Terjan <pterjan@mandriva.org> 0.45.1-4mdv2008.0
+ Revision: 89124
- Update BuildRequires as liblcms was renamed to lcms
- Drop icon extension in .desktop
- Have inkscape in the main part of the menu under KDE
- Fix build with new intltool
- Fix build with new sigc++

* Tue Jul 03 2007 Michael Scherer <misc@mandriva.org> 0.45.1-3mdv2008.0
+ Revision: 47534
- rebuild for new glib

* Fri Jun 22 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 0.45.1-2mdv2008.0
+ Revision: 43219
- Added autotools patch: update to work with current autotools scheme.
- Rebuild against new glib

* Tue May 15 2007 Funda Wang <fwang@mandriva.org> 0.45.1-1mdv2008.0
+ Revision: 26827
- Patch1 merged upsream.
- New upstream version


* Sat Mar 24 2007 Pascal Terjan <pterjan@mandriva.org> 0.45-2mdv2007.1
+ Revision: 148707
- Add patch from MDKSA-2007:069

* Mon Feb 05 2007 Pascal Terjan <pterjan@mandriva.org> 0.45-1mdv2007.1
+ Revision: 116515
- 0.45
- fix build with new GCC

* Tue Oct 24 2006 Pascal Terjan <pterjan@mandriva.org> 0.44.1-1mdv2007.0
+ Revision: 71737
- Buildrequires intltool
- 0.44.1
- Fix building with new automake
- Import inkscape

* Thu Aug 24 2006 Götz Waschk <waschk@mandriva.org> 0.44-4mdv2007.0
- fix buildrequires
- rebuild for new cairomm

* Sat Aug 12 2006 Anssi Hannula <anssi@mandriva.org> 0.44-3mdv2007.0
- add BuildRequires: dbus-devel

* Sat Jul 15 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.44-2
- add BuildRequires: liblcms-devel

* Sat Jun 24 2006 Pascal Terjan <pterjan@mandriva.org>  0.44-1mdv2007.0
- 0.44
- Use XDG menu
- Drop P0 and P1 (fixed upstream)
- Remove --with-perl this is an experimental and broken currently useless
  build option

* Mon Jun 05 2006 Pascal Terjan <pterjan@mandriva.org>  0.43-5mdv2007.0
- BuildRequires expat-devel

* Sat Jun 03 2006 Pascal Terjan <pterjan@mandriva.org>  0.43-4mdv2007.0
- BuildRequires gnome-vfs-devel
- fix for gcc 4.1 (P0)
- apply upstream patch to not use freetype internals (P1)

* Thu Feb 09 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.43-3mdk
- require python-pyxml (#20099)

* Wed Jan 25 2006 Pascal Terjan <pterjan@mandriva.org>  0.43-2mdk
- Rebuild for new perl

* Mon Nov 21 2005 Michael Scherer <misc@mandriva.org> 0.43-1mdk
- New release 0.43
- activation of inkboard

* Tue Jul 26 2005 Pascal Terjan <pterjan@mandriva.org> 0.42-1mdk
- 0.42
- Drop P0, included upstream

* Thu Jul 07 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.41-5mdk
- work around weird problem when linking against popt (lib64)
- %%mkrel
- drop COPYING (package is GPL..)

* Fri May 20 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 0.41-4mdk
- Rebuild for new perl

* Tue Apr 05 2005 Pascal Terjan <pterjan@mandrake.org> 0.41-3mdk
- BuildRequires perl-devel for EXTERN.h

* Tue Mar 01 2005 Abel Cheung <deaddog@mandrake.org> 0.41-2mdk
- Fixes done by Tom Ph <tpgww@onepost.net>:
  o Patch (missing gnomeprint fn) from CVS
  o Add back gnomeprint support
  o Extra icons, menu icon
  o Requires, BuildRequires

* Sat Feb 26 2005 Abel Cheung <deaddog@mandrake.org> 0.41-1mdk
- New release
- Drop gnomeprint support (compile error)

* Thu Dec 02 2004 Abel Cheung <deaddog@mandrake.org> 0.40-2mdk
- Update BuildRequires

* Tue Nov 30 2004 Jerome Soyer <saispo@mandrake.org> 0.40-1mdk
- New release 0.40

* Tue Sep 21 2004 Jerome Soyer <saispo@mandrake.org> 0.39-4mdk
- Update BuildRequires

* Tue Sep 21 2004 Jerome Soyer <saispo@mandrake.org> 0.39-3mdk
- Added Autotrace and Frontline function

* Mon Aug 30 2004 Jerome Soyer <saispo@mandrake.org> 0.39-2mdk
- fix BuildRequires

* Thu Jul 22 2004 Michael Scherer <misc@mandrake.org> 0.39-1mdk
- New release 0.39
- remove patch 0, integrated upstream

* Sun Jun 20 2004 Abel Cheung <deaddog@deaddog.org> 0.38.1-4mdk
- Patch0: fix build against new gcc (CVS)

* Thu Jun 03 2004 Michael Scherer <misc@mandrake.org> 0.38.1-3mdk 
- [DIRM]

* Fri Apr 23 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.38.1-2mdk
- fix deps

* Tue Apr 13 2004 Michael Scherer <misc@mandrake.org> 0.38.1-1mdk
- New release 0.38.1
- [DIRM]

